/**********************************************************************************************/
/* FBL_LanguageManager.h																	  */
/*                                                                       					  */
/* Foundation Base Library ( FBL 1.0 )														  */
/*                                                                       					  */
/* Copyright Paradigma, 1993-2002															  */
/* All Rights Reserved                                                   					  */
/**********************************************************************************************/

#ifndef __FBL_LanguageManager_h 
	#define __FBL_LanguageManager_h

#if VSDK_FRAMEWORK_STYLE
#	include <VSDK/FBL.h>
#	include <VSDK/FBL_String.h>
#	include <VSDK/FBL_StringUtilities.h>
#else
#	include <FBL.h>
#	include <FBL_String.h>
#	include <FBL_StringUtilities.h>
#endif // VSDK_FRAMEWORK_STYLE

#if defined(__MWERKS__)
	#pragma options align=power
#endif


/**********************************************************************************************/
#if FBL_MAC
	typedef long OSLocale;			
#elif FBL_WIN
	typedef LCID OSLocale;
#endif


/**********************************************************************************************/
class FBL_EXP FBL_Language
{
		friend class FBL_LanguageManager;

	public://///////////////////////////////////////////////////////////////////////////////////
	 
	 							FBL_Language( const char* inLanguage );
								~FBL_Language( void );
								
const 	FBL_String& 			GetLanguageName( void ) const		{ return mLanguage; }
		FBL_CompareStringPtr	GetCompareFunction( void ) const 	{ return mCompare; }

#ifdef FBL_MAC
		Handle					GetItl2Handle( void ) const 		{ return mItl2Handle; }
#elif FBL_WIN
		LCID					GetLanguageID( void ) const 		{ return mLanguageID; }
#endif

		uchar					GetMaxChar( void ) const			{ return mMaxChar; }

	protected:////////////////////////////////////////////////////////////////////////////////// 

#ifdef FBL_MAC
		void					SetItl2Handle( Handle inItl2 );			
#elif FBL_WIN

#endif


	protected:////////////////////////////////////////////////////////////////////////////////// 

		FBL_String				mLanguage;			// e.g. "German"
		FBL_CompareStringPtr	mCompare;			// function pointer.
		uchar					mMaxChar;

#ifdef FBL_MAC
   		Handle  				mItl2Handle;
#elif FBL_WIN 
		LCID					mLanguageID;		// long value, PrimaryLang + SecondaryLang	
#endif

};


/**********************************************************************************************/
struct FBL_LanguageMap
{
	FBL_String	langName;
	long 		id;				// id of MacOS resource for this language.	
};	


/**********************************************************************************************/
typedef FBL_Array<FBL_Language*> 	ArrayOfLanguages;
typedef FBL_Array<FBL_LanguageMap*> LanguageMap;


/**********************************************************************************************/
class FBL_EXP FBL_LanguageManager
{
		friend class FBL_Language;

	public://///////////////////////////////////////////////////////////////////////////////////
	 
static 	const char* 			sLanguageNames[];	// Array of language names;
static 	short					sLanguageNameCount;		


	public://///////////////////////////////////////////////////////////////////////////////////
	 
static	void					InitStaticMembers( void );	
static	void					DestroyStaticMembers( void );

static	FBL_Language*			GetLanguage( const char* inLanguageName );

								// this is needed to convert old format with langID to langName 
static	FBL_Language*			GetLanguage( short inLangID );
	
static	OSLocale	 			DoGetLanguageID( FBL_String inLanguage );
		
								
static	short					GetLanguageCount( void );	
static	const char*				GetLanguageName( ushort inIndex );	
	
	protected:////////////////////////////////////////////////////////////////////////////////// 

#ifdef FBL_MAC
	static	Handle				DoGetItl2( long ID );
#endif

	protected:////////////////////////////////////////////////////////////////////////////////// 

static 	LanguageMap*			sLanguageMap;		// Array of language - id pairs (for MacOS)
static	ArrayOfLanguages*		sLanguages;			// Array of instances of FBL_Language.

};


/**********************************************************************************************/
#if defined(__MWERKS__)
	#pragma options align=reset
#endif

#endif  
