/**********************************************************************************************/
/* FBL_StringUtilities.h                                                         			  */
/*                                                                       					  */
/* Foundation Base Library ( FBL )		                                   					  */
/*                                                                       					  */
/* Copyright Paradigma, 1993-2002															  */
/* All Rights Reserved                                                   					  */
/**********************************************************************************************/

#ifndef __FBL_StringUtilities_h 
	#define __FBL_StringUtilities_h

#if VSDK_FRAMEWORK_STYLE
#	include <VSDK/FBL.h>
#else
#	include <FBL.h>
#endif // VSDK_FRAMEWORK_STYLE

#if defined(__MWERKS__)
	#pragma options align=power
#endif


/**********************************************************************************************/
class FBL_Language;


/**********************************************************************************************/
// Copy C-string to the pascal string.
// Can't be used for Unicode, because it assume that c-string is zero-end. 
FBL_EXP void FBL_c2pstrcpy( 
	const char* 	inSrc, 
	StringPtr 		inDest,
	ushort			inMaxChars = 255 );
		
		
/**********************************************************************************************/
// Copy pascal string to C string. Can't be used for the same buffer, because use memcpy.
FBL_EXP void FBL_p2cstrcpy( 
	const StringPtr inDest, 
	char* 			inSrc, 
	ushort			inBuffSize = 256 );
								

/**********************************************************************************************/
FBL_EXP StringPtr FBL_AppendPStr(	
	Str255			ioBaseString,
	ConstStringPtr	inAppendString,
	short			inDestSize = 256 );


/**********************************************************************************************/
typedef short (*FBL_CompareStringPtr)( 
	const void* str1, ushort len1,
	const void* str2, ushort len2,
	FBL_Language* inLanguage ); 


/**********************************************************************************************/
// compare byte-to-byte 2 strins.
// It is good for example for English language.
// Can be used only for 1-byte languages.

FBL_EXP 
short FBL_CompareBytes( 
		const void* str1, ushort len1,
		const void* str2, ushort len2,
		FBL_Language* inLanguage );

FBL_EXP 
short FBL_InternationalCompare( 
		const void* str1, ushort len1,
		const void* str2, ushort len2,
		FBL_Language* inLanguage );
	

/**********************************************************************************************/
FBL_EXP bool MatchRegularExpr( const char* inTestString, const char* inWildCard );


/**********************************************************************************************/
FBL_EXP FBL_String* ExtractStringValue( char*& p, char* pEnd );
FBL_EXP FBL_String 	ExtractName( char*& ioPtr, char* inEnd );


/**********************************************************************************************/
struct FBL_SystemLang
{
	short	mMac;
	ushort	mWinPrimary;
	ushort	mWinSubLang;
};


/**********************************************************************************************/
// prepends ', " characters in the input string with \ (backslash); 
// inRegEx parameter allows to escape some characters used when 
// building RegEx expression ( [, ], (, ) ); note, that function 
// dynamically allocates memory for the result string, 
// so the char* pointer returned must be freed to avoid memory leak
// 
FBL_EXP char* EscapeString( const char* inStr, bool inRegEx );

FBL_EXP char* EscapeString( 
					const char* inStr, 
					bool		inRegEx,
					char*		outBuffer, 
					ulong		inBufferLength );



/**********************************************************************************************/
#if defined(__MWERKS__)
	#pragma options align=reset
#endif

#endif
